#
# spec file for package python-sphobjinv
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-sphobjinv
Version:        2.3.1
Release:        2.4
Summary:        Sphinx objectsinv Inspection/Manipulation Tool
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/bskinn/sphobjinv
Source:         https://github.com/bskinn/sphobjinv/archive/refs/tags/v%{version}.tar.gz#/sphobjinv-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs >= 19.2
Requires:       python-certifi
Requires:       python-jsonschema >= 3.0
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Sphinx}
BuildRequires:  %{python_module attrs >= 19.4}
BuildRequires:  %{python_module certifi}
BuildRequires:  %{python_module dictdiffer}
BuildRequires:  %{python_module jsonschema >= 3.0}
BuildRequires:  %{python_module pytest >= 4.4.0}
BuildRequires:  %{python_module pytest-check >= 1.1.2}
BuildRequires:  %{python_module pytest-timeout}
BuildRequires:  %{python_module sphinx_rtd_theme}
# /SECTION
%python_subpackages

%description
Sphinx objects.inv Inspection/Manipulation Tool

%prep
%setup -q -n sphobjinv-%{version}
sed -i '1{/^#!/d}' src/sphobjinv/_vendored/fuzzywuzzy/*.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/sphobjinv
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# we don't have stdio-mgr
ignoretests="--ignore tests/test_cli.py --ignore tests/test_cli_nonlocal.py"
# Errors with invalid inventory source type: we didn't build the docs and don't have the inventory there
sed -i 's/--doctest-glob="README.rst"//' tox.ini
%pytest $ignoretests

%post
%python_install_alternative sphobjinv

%postun
%python_uninstall_alternative sphobjinv

%files %{python_files}
%doc CHANGELOG.md README.rst
%license LICENSE.txt
%python_alternative %{_bindir}/sphobjinv
%{python_sitelib}/sphobjinv
%{python_sitelib}/sphobjinv-%{version}*-info

%changelog
* Wed Mar 27 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Dec 15 2023 Dirk Müller <dmueller@suse.com>
- update to 2.3.1:
  * The printout of the inferred `intersphinx_mapping` item for
    inventories retrieved by URL (`--url`) in the 'suggest' CLI
    mode is now relocated to fall immediately below the
    inventory-search output.
  * The 'suggest' CLI mode output now includes dividers for
    improved readability.
  * `MANIFEST.in` was revised in order to provide a testable
    (`pytest --nonloc`)
  * sdist, in order to streamline packaging of `sphobjinv` for
    conda-forge.
  * The version constraint for `pytest-check` was raised to
    `>=1.1.2`.
  * The CLI now prints the project name and version for the
    `objects.inv` as  part of the 'suggest' mode output.
  * The CLI now prints an inferred `intersphinx_mapping` entry
    for a remote docset as part of the 'suggest' mode output,
    where such inference is possible. The output from this mapping
    inference was added to the relevant tests, and a couple of
    unit tests on some basic pieces of functionality were
    written.
  * The CLI now provides considerably more information about what
    is happening with the URLs it checks when trying to retrieve a
    remote inventory.
  * CLI 'suggest' results output now displays more information
    about the total number of objects in the inventory, the search
    score threshold, and the number of results falling at/above
    that threshold.
  * A new CLI option, `-p`/`--paginate`, enables paging of the
    results from the `suggest` feature. (#70)
* Thu Jul 14 2022 Ben Greiner <code@bnavigator.de>
- Update to version 2.2.2
  * CLI 'suggest' results output now displays more information
    about the total number of objects in the inventory, the search
    score threshold, and the number of results falling at/above
    that threshold.
  * UnicodeDecodeErrors are ignored within the vendored fuzzywuzzy
    package during suggest operations, using the errors=replace
    mode within bytes.decode().
  * This misbehavior emerged after vendoring fuzzywuzzy, suggesting
    that it was a bug fixed later on in that project's development,
    after the point from which it was vendored.
  * This change may alter suggest behavior for those inventory
    objects with pathological characters. But, given their rarity,
    user experience is not expected to be noticeably affected.
- Release 2.2
  * Acceleration of the suggest functionality via use of
    python-Levenshtein is no longer possible due to the vendoring
    of an early, MIT-licensed version of fuzzywuzzy, as noted
    below. The speedup install extra is now obsolete, and has been
    removed.
  * The fuzzywuzzy string matcher was vendored into the project
    from a point in its development history before the
    python-Levenshtein dependency, and its corresponding GPL
    encumbrance, was introduced.
  * Active support for Python 3.11 added.
- Release 2.1
  * Python 3.10 support was officially added.
  * The User-Agent header sent by Inventory when making an HTTP(S)
    request now identifies sphobjinv and its version (anticipate no
    API or behavior change).
  * An extraneous newline was removed before tables printed in the
    'suggest' CLI mode (cosmetic change).
  * Previously, sphobjinv.Inventory would ignore entries in
    objects.inv that contained spaces within name (see #181); this
    is now fixed.
  * Python 3.5 is no longer supported.
  * The relaxation of the integer constraint on the priority field
    introduced in v2.1b1 has been reverted, as objects.inv data
    lines with such non-integer priority values are skipped by
    Sphinx.
  * Equality tests on Inventory and DataObjStr/DataObjBytes
    instances now work correctly.
  * Non-integer and non-numeric values for priority are now
    accepted during Inventory instantiation, consistent with what
    is allowed by DataObjStr and DataObjBytes instantiation.
  * When an inventory is retrieved via CLI from a remote URL with
  - u, the resolved location of the inventory is included in
    generated JSON at json_dict.metadata.url.
  * CLI logging messages are now emitted to stderr instead of
    stdout.
  * A hyphen can now be passed as the CLI input and/or output file
    name to instruct sphobjinv to use stdin and/or stdout,
    respectively.
  * The fileops and inventory APIs are now tested to work with both
    strings and pathlib.Path objects, where they interact with the
    filesystem.
- Enable test suite
- Remove ancient python-pathlib dependency
* Tue May 19 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Fri Mar  6 2020 pgajdos@suse.com
- initial version 2.0.1, required by python-sphinx-autodoc-typehints
  testsuite
